@@ -276,7 +276,7 @@ set_date_completed (E2kProperties *props, ECalComponent *comp)
 	}
 
 	icaltimezone_convert_time (itt,
-				   icaltimezone_get_builtin_timezone ((const gchar *)itt->zone),
+				   icaltimezone_get_builtin_timezone ((const gchar *) itt->zone),
 				   icaltimezone_get_utc_timezone ());
 	tstr = icaltime_to_e2k_time (itt);
 	e_cal_component_free_icaltimetype (itt);
@@ -633,7 +633,7 @@ get_changed_tasks (ECalBackendExchange *cbex)
 		ecal = e_cal_component_new ();
 		icalcomp = icalcomponent_new_vtodo ();
 		e_cal_component_set_icalcomponent (ecal, icalcomp);
-		e_cal_component_set_uid (ecal, (const gchar *)uid);
+		e_cal_component_set_uid (ecal, (const gchar *) uid);
 
 		modtime = e2k_properties_get_prop (result->props,
 						   E2K_PR_DAV_LAST_MODIFIED);
@@ -703,7 +703,7 @@ get_changed_tasks (ECalBackendExchange *cbex)
 			sl.data = &text;
 			sl.next = NULL;
 			e_cal_component_set_description_list (E_CAL_COMPONENT (ecal), &sl);
-			g_free ((gchar *)text.value);
+			g_free ((gchar *) text.value);
 		}
 
 		/* Set DUE */
@@ -711,7 +711,7 @@ get_changed_tasks (ECalBackendExchange *cbex)
 			itzone = get_default_timezone ();
 			itt = icaltime_from_timet_with_zone (e2k_parse_timestamp (str), 0, itzone);
 			if (!icaltime_is_null_time (itt)) {
-				tzid = icaltimezone_get_tzid ((icaltimezone *)itzone);
+				tzid = icaltimezone_get_tzid ((icaltimezone *) itzone);
 				ecdatetime.value = &itt;
 				ecdatetime.tzid = tzid;
 				e_cal_component_set_due (ecal, &ecdatetime);
@@ -724,7 +724,7 @@ get_changed_tasks (ECalBackendExchange *cbex)
 			itzone = get_default_timezone ();
 			itt = icaltime_from_timet_with_zone (e2k_parse_timestamp (str), 0, itzone);
 			if (!icaltime_is_null_time (itt)) {
-				tzid = icaltimezone_get_tzid ((icaltimezone *)itzone);
+				tzid = icaltimezone_get_tzid ((icaltimezone *) itzone);
 				ecdatetime.value = &itt;
 				ecdatetime.tzid = tzid;
 				e_cal_component_set_dtstart (ecal, &ecdatetime);
@@ -854,7 +854,6 @@ get_changed_tasks (ECalBackendExchange *cbex)
 		g_hash_table_destroy (modtimes);
 		g_hash_table_destroy (attachments);
 		g_mutex_unlock (cbext->priv->mutex);
-		g_object_unref (cbext);
 		return status;
 	}
 
@@ -869,13 +868,12 @@ get_changed_tasks (ECalBackendExchange *cbex)
 		g_hash_table_destroy (attachments);
 		cbext->priv->is_loaded = TRUE;
 		g_mutex_unlock (cbext->priv->mutex);
-		g_object_unref (cbext);
 		return SOUP_STATUS_OK;
 	}
 
 	prop = PR_INTERNET_CONTENT;
 	iter = e_folder_exchange_bpropfind_start (cbex->folder, NULL,
-						(const gchar **)hrefs->pdata,
+						(const gchar **) hrefs->pdata,
 						hrefs->len, &prop, 1);
 	for (i = 0; i < hrefs->len; i++)
 		g_free (hrefs->pdata[i]);
@@ -915,7 +913,6 @@ get_changed_tasks (ECalBackendExchange *cbex)
 		g_ptr_array_free (hrefs, TRUE);
 		g_hash_table_destroy (attachments);
 		g_mutex_unlock (cbext->priv->mutex);
-		g_object_unref (cbext);
 		return status;
 	}
 
@@ -924,14 +921,12 @@ get_changed_tasks (ECalBackendExchange *cbex)
 		g_hash_table_destroy (attachments);
 		cbext->priv->is_loaded = TRUE;
 		g_mutex_unlock (cbext->priv->mutex);
-		g_object_unref (cbext);
 		return SOUP_STATUS_OK;
 	}
 
 	ctx = exchange_account_get_context (cbex->account);
 	if (!ctx) {
 		g_mutex_unlock (cbext->priv->mutex);
-		g_object_unref (cbext);
 		/* This either means we lost connection or we are in offline mode */
 		return SOUP_STATUS_CANT_CONNECT;
 	}
@@ -972,8 +967,6 @@ get_changed_tasks (ECalBackendExchange *cbex)
 		cbext->priv->is_loaded = TRUE;
 
 	g_mutex_unlock (cbext->priv->mutex);
-	g_object_unref (cbext);
-
 	return status;
 }
 
@@ -988,27 +981,24 @@ notify_changes (E2kContext *ctx, const gchar *uri,
 	g_return_if_fail (E_IS_CAL_BACKEND_EXCHANGE (ecalbex));
 	g_return_if_fail (uri != NULL);
 
-	get_changed_tasks (g_object_ref (ecalbex));
+	get_changed_tasks (ecalbex);
 
 }
 
 static void
-open_task (ECalBackendSync *backend, EDataCal *cal,
-	   gboolean only_if_exits,
-	   const gchar *username, const gchar *password, GError **perror)
+authenticate_user_task (ECalBackendSync *backend, GCancellable *cancellable, ECredentials *credentials, GError **perror)
 {
 	GThread *thread = NULL;
 	GError *error = NULL;
 	ECalBackendExchangeTasks *cbext = E_CAL_BACKEND_EXCHANGE_TASKS (backend);
 
-	E_CAL_BACKEND_SYNC_CLASS (parent_class)->open_sync (backend,
-				     cal, only_if_exits, username, password, &error);
+	E_CAL_BACKEND_SYNC_CLASS (parent_class)->authenticate_user_sync (backend, cancellable, credentials, &error);
 	if (error) {
 		g_propagate_error (perror, error);
 		return;
 	}
 
-	if (!e_cal_backend_exchange_is_online (E_CAL_BACKEND_EXCHANGE (backend))) {
+	if (!e_cal_backend_is_online (E_CAL_BACKEND (backend))) {
 		d(printf ("ECBEC : calendar is offline\n"));
 		return;
 	}
@@ -1027,20 +1017,19 @@ open_task (ECalBackendSync *backend, EDataCal *cal,
 					E2K_CONTEXT_OBJECT_REMOVED, 30,
 					notify_changes, backend);
 
-	thread = g_thread_create ((GThreadFunc) get_changed_tasks, g_object_ref (backend), FALSE, &error);
+	thread = g_thread_create ((GThreadFunc) get_changed_tasks, E_CAL_BACKEND_EXCHANGE (backend), FALSE, &error);
 	if (!thread) {
 		g_propagate_error (perror, EDC_ERROR_EX (OtherError, error->message));
 		g_error_free (error);
-		g_object_unref (backend);
 	}
 }
 
 static void
-refresh_task (ECalBackendSync *backend, EDataCal *cal, GError **perror)
+refresh_task (ECalBackendSync *backend, EDataCal *cal, GCancellable *cancellable, GError **perror)
 {
 	g_return_if_fail (E_IS_CAL_BACKEND_EXCHANGE (backend));
 
-	get_changed_tasks (g_object_ref (backend));
+	get_changed_tasks (E_CAL_BACKEND_EXCHANGE (backend));
 }
 
 struct _cb_data {
@@ -1050,8 +1039,8 @@ struct _cb_data {
 };
 
 static void
-create_task_object (ECalBackendSync *backend, EDataCal *cal,
-		    gchar **calobj, gchar **return_uid, GError **error)
+create_task_object (ECalBackendSync *backend, EDataCal *cal, GCancellable *cancellable,
+		    const gchar *calobj, gchar **return_uid, gchar **new_object, GError **error)
 {
 	ECalBackendExchange *ecalbex;
 	E2kProperties *props;
@@ -1075,14 +1064,14 @@ create_task_object (ECalBackendSync *backend, EDataCal *cal,
 
 	e_return_data_cal_error_if_fail (calobj != NULL, InvalidArg);
 
-	if (!e_cal_backend_exchange_is_online (E_CAL_BACKEND_EXCHANGE (backend))) {
+	if (!e_cal_backend_is_online (E_CAL_BACKEND (backend))) {
 		d(printf ("tasks are offline\n"));
 		g_propagate_error (error, EDC_ERROR (RepositoryOffline));
 		return;
 	}
 
 	/* Parse the icalendar text */
-	icalcomp = icalparser_parse_string (*calobj);
+	icalcomp = icalparser_parse_string (calobj);
 	if (!icalcomp) {
 		g_propagate_error (error, EDC_ERROR (InvalidObject));
 		return;
@@ -1180,8 +1169,8 @@ create_task_object (ECalBackendSync *backend, EDataCal *cal,
 
 	update_props (comp, &props);
 	e_cal_component_commit_sequence (comp);
-	*calobj = e_cal_component_get_as_string (comp);
-	if (!*calobj) {
+	*new_object = e_cal_component_get_as_string (comp);
+	if (!*new_object) {
 		g_object_unref (comp);
 		g_free (from_name);
 		g_free (from_addr);
@@ -1189,7 +1178,7 @@ create_task_object (ECalBackendSync *backend, EDataCal *cal,
 		return;
 	}
 
-	real_icalcomp = icalparser_parse_string (*calobj);
+	real_icalcomp = icalparser_parse_string (*new_object);
 
 	e2kctx = exchange_account_get_context (ecalbex->account);
 	status = e_folder_exchange_proppatch_new (ecalbex->folder, NULL,
@@ -1219,7 +1208,7 @@ create_task_object (ECalBackendSync *backend, EDataCal *cal,
 }
 
 static void
-modify_task_object (ECalBackendSync *backend, EDataCal *cal,
+modify_task_object (ECalBackendSync *backend, EDataCal *cal, GCancellable *cancellable,
 	       const gchar *calobj, CalObjModType mod,
 	       gchar **old_object, gchar **new_object, GError **error)
 {
@@ -1245,7 +1234,7 @@ modify_task_object (ECalBackendSync *backend, EDataCal *cal,
 	e_return_data_cal_error_if_fail (E_IS_CAL_BACKEND_EXCHANGE_TASKS (ecalbextask), InvalidArg);
 	e_return_data_cal_error_if_fail (calobj != NULL, InvalidArg);
 
-	if (!e_cal_backend_exchange_is_online (E_CAL_BACKEND_EXCHANGE (backend))) {
+	if (!e_cal_backend_is_online (E_CAL_BACKEND (backend))) {
 		d(printf ("tasks are offline\n"));
 		g_propagate_error (error, EDC_ERROR (RepositoryOffline));
 		return;
@@ -1347,7 +1336,7 @@ modify_task_object (ECalBackendSync *backend, EDataCal *cal,
 }
 
 static void
-receive_task_objects (ECalBackendSync *backend, EDataCal *cal,
+receive_task_objects (ECalBackendSync *backend, EDataCal *cal, GCancellable *cancellable,
                  const gchar *calobj, GError **error)
 {
 	ECalBackendExchangeTasks *ecalbextask;
@@ -1365,7 +1354,7 @@ receive_task_objects (ECalBackendSync *backend, EDataCal *cal,
 	e_return_data_cal_error_if_fail (E_IS_CAL_BACKEND_EXCHANGE_TASKS (ecalbextask), InvalidArg);
 	e_return_data_cal_error_if_fail (calobj != NULL, InvalidArg);
 
-	if (!e_cal_backend_exchange_is_online (E_CAL_BACKEND_EXCHANGE (backend))) {
+	if (!e_cal_backend_is_online (E_CAL_BACKEND (backend))) {
 		d(printf ("tasks are offline\n"));
 		g_propagate_error (error, EDC_ERROR (RepositoryOffline));
 		return;
@@ -1399,7 +1388,7 @@ receive_task_objects (ECalBackendSync *backend, EDataCal *cal,
 			gchar *old_object;
 
 			e_cal_backend_exchange_cache_unlock (cbex);
-			modify_task_object (backend, cal, calobj, CALOBJ_MOD_THIS, &old_object, NULL, &err);
+			modify_task_object (backend, cal, cancellable, calobj, CALOBJ_MOD_THIS, &old_object, NULL, &err);
 			if (err) {
 				g_free (rid);
 				g_propagate_error (error, err);
@@ -1409,20 +1398,21 @@ receive_task_objects (ECalBackendSync *backend, EDataCal *cal,
 			e_cal_backend_notify_object_modified (E_CAL_BACKEND (backend), old_object, calobj);
 			g_free (old_object);
 		} else {
-			gchar *returned_uid;
+			gchar *returned_uid, *new_object = NULL;
 
 			e_cal_backend_exchange_cache_unlock (cbex);
 			calobj = (gchar *) icalcomponent_as_ical_string_r (subcomp);
-			create_task_object (backend, cal, &calobj, &returned_uid, &err);
+			create_task_object (backend, cal, cancellable, calobj, &returned_uid, &new_object, &err);
+			g_free (calobj);
 			if (err) {
-				g_free (calobj);
+				g_free (new_object);
 				g_free (rid);
 				g_propagate_error (error, err);
 				return;
 			}
 
-			e_cal_backend_notify_object_created (E_CAL_BACKEND (backend), calobj);
-			g_free (calobj);
+			e_cal_backend_notify_object_created (E_CAL_BACKEND (backend), new_object);
+			g_free (new_object);
 		}
 		g_free (rid);
 	}
@@ -1431,7 +1421,7 @@ receive_task_objects (ECalBackendSync *backend, EDataCal *cal,
 }
 
 static void
-remove_task_object (ECalBackendSync *backend, EDataCal *cal,
+remove_task_object (ECalBackendSync *backend, EDataCal *cal, GCancellable *cancellable,
 	       const gchar *uid, const gchar *rid, CalObjModType mod,
 	       gchar **old_object, gchar **object, GError **error)
 {
@@ -1443,7 +1433,7 @@ remove_task_object (ECalBackendSync *backend, EDataCal *cal,
 
 	e_return_data_cal_error_if_fail (E_IS_CAL_BACKEND_EXCHANGE (ecalbex), InvalidArg);
 
-	if (!e_cal_backend_exchange_is_online (E_CAL_BACKEND_EXCHANGE (backend))) {
+	if (!e_cal_backend_is_online (E_CAL_BACKEND (backend))) {
 		d(printf ("tasks are offline\n"));
 		g_propagate_error (error, EDC_ERROR (RepositoryOffline));
 		return;
@@ -1515,7 +1505,7 @@ class_init (ECalBackendExchangeTasksClass *klass)
 
 	parent_class = g_type_class_peek_parent (klass);
 
-	sync_class->open_sync = open_task;
+	sync_class->authenticate_user_sync = authenticate_user_task;
 	sync_class->refresh_sync = refresh_task;
 	sync_class->create_object_sync = create_task_object;
 	sync_class->modify_object_sync = modify_task_object;
